# Table of Contents

1 Table of Contents
{%- if header %} {{ header }} {%- endif %} {%- if attachments %}

# User Documentation

{%- for attachment in attachments %}
- {{ attachment.title }}
{%- endfor %}

{%- endif %} {%- if releases %}

# Release Notes

{%- for release in releases %}

## Version {{ release.name }}

{%- if release.release_date %}
- Release date: {{ release.release_date }}
{%- endif %} {%- if release.description %}
- Description: {{ release.description }}
{%- endif %}

{%- for topic in release.topics %} {%- if topic.issues %}

## {{ topic.name }}

{%- for issue in topic.issues %}
- {{ issue.key }} {{ issue.title }} {%- if issue.description %}
  - {{ issue.description }}
  {%- endif %}
{%- endfor %}

{%- endif %} {%- endfor %}

{%- endfor %} {%- endif %} {%- if footer %} {{ footer }} {%- endif %}